@@ -164,6 +164,7 @@ sub EXT_dialog : Extend('Ext.Dialog') : Type('widget') {
     };
 }
 
+# FORMS
 sub EXT_signin_form : Extend('Ext.Panel') {
     return {
         keyMap => { ENTER => 'doSignin' },
@@ -174,7 +175,7 @@ sub EXT_signin_form : Extend('Ext.Panel') {
                 items => [
                     {   xtype      => 'textfield',
                         name       => 'username',
-                        label      => l10n('Email'),
+                        label      => l10n('User Name or Email'),
                         allowBlank => \0,
                         required   => \1,
                     },
@@ -321,7 +322,7 @@ sub EXT_recover_password_form : Extend('Ext.Panel') {
                 items => [
                     {   xtype      => 'textfield',
                         name       => 'username',
-                        label      => l10n('User Name'),
+                        label      => l10n('User Name or Email'),
                         allowBlank => \0,
                         required   => \1,
                     },
