@@ -44,7 +44,7 @@ JS
             var view = this.getView(),
                 redirectOnClose = view.getRedirectOnClose();
 
-            if (redirectOnClose != null) this.redirectTo(redirectOnClose);
+            if (redirectOnClose != null) this.redirectTo(redirectOnClose, {replace: true});
 JS
     };
 }
